window.Gleam.initSearch([{"doc":"wink","title":"wink","content":"# wink\n\n[![Package Version](https://img.shields.io/hexpm/v/wink)](https://hex.pm/packages/wink)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/wink/)\n\nA simple Gleam box drawing library\n\n```sh\ngleam add wink\n```\n\n```gleam\nimport gleam/io\nimport wink\n\npub fn main() {\n    // draws a box with the default configuration\n    &quot;(&gt;ᴗ•)&quot;\n    |&gt; wink.draw\n    |&gt; io.println\n}\n```\n\nwill output:\n\n```\n\n ╭───────╮ \n │       │ \n │ (&gt;ᴗ•) │ \n │       │ \n ╰───────╯ \n\n```\n\n```gleam\nimport gleam/io\nimport wink.{Border, Config, Custom}\n\npub fn main() {\n    // or you can initialize a custom-styled box with specific config\n    let box =\n      wink.init(\n        Config(\n          ..wink.default_config,\n          style: Custom(Border(\n            top_right: &quot;◝&quot;,\n            top_left: &quot;◜&quot;,\n            bottom_right: &quot;◞&quot;,\n            bottom_left: &quot;◟&quot;,\n            horizontal: &quot;―&quot;,\n            vertical: &quot;⸾&quot;,\n          )),\n        ),\n      )\n\n    &quot;(&gt;ᴗ•)&quot;\n    |&gt; box.draw\n    |&gt; io.println\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/wink&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n","url":"index.html"},{"doc":"wink","title":"Border","content":"pub type Border {\n  Border(\n    top_right: String,\n    top_left: String,\n    bottom_right: String,\n    bottom_left: String,\n    horizontal: String,\n    vertical: String,\n  )\n}\n Represents the borders of a box.\n\nBorder(\n  top_right: String,\n  top_left: String,\n  bottom_right: String,\n  bottom_left: String,\n  horizontal: String,\n  vertical: String,\n)\n\n\nSynonyms:\nwink.Border\nwink Border","url":"wink.html#Border"},{"doc":"wink","title":"Box","content":"pub type Box {\n  Box(draw: fn(String) -&gt; String)\n}\n Represents a box instance.\n\nBox(draw: fn(String) -&gt; String)\n\n\nSynonyms:\nwink.Box\nwink Box","url":"wink.html#Box"},{"doc":"wink","title":"Color","content":"pub type Color {\n  Black\n  Red\n  Green\n  Yellow\n  Blue\n  Magenta\n  Cyan\n  White\n  Default\n  ResetColor\n}\n Represents different colors for drawing boxes.\n\nBlack\n\n\nRed\n\n\nGreen\n\n\nYellow\n\n\nBlue\n\n\nMagenta\n\n\nCyan\n\n\nWhite\n\n\nDefault\n\n\nResetColor\n\n\nSynonyms:\nwink.Color\nwink Color","url":"wink.html#Color"},{"doc":"wink","title":"Config","content":"pub type Config {\n  Config(\n    style: Style,\n    box_color: Color,\n    text_color: Color,\n    padding: Spacing,\n    margin: Spacing,\n    decorations: List(Decoration),\n  )\n}\n Represents the configuration for drawing a box.\n\nConfig(\n  style: Style,\n  box_color: Color,\n  text_color: Color,\n  padding: Spacing,\n  margin: Spacing,\n  decorations: List(Decoration),\n)\n\n\nSynonyms:\nwink.Config\nwink Config","url":"wink.html#Config"},{"doc":"wink","title":"Decoration","content":"pub type Decoration {\n  Bold\n  Dim\n  Italic\n  Underline\n  Reversed\n  ResetDecoration\n}\n Represents different decorations for text.\n\nBold\n\n\nDim\n\n\nItalic\n\n\nUnderline\n\n\nReversed\n\n\nResetDecoration\n\n\nSynonyms:\nwink.Decoration\nwink Decoration","url":"wink.html#Decoration"},{"doc":"wink","title":"Spacing","content":"pub type Spacing {\n  Spacing(top: Int, right: Int, bottom: Int, left: Int)\n}\n Represents spacing around the content of a box.\n\nSpacing(top: Int, right: Int, bottom: Int, left: Int)\n\n\nSynonyms:\nwink.Spacing\nwink Spacing","url":"wink.html#Spacing"},{"doc":"wink","title":"Style","content":"pub type Style {\n  Single\n  Round\n  Solid\n  Frame\n  Cross\n  Spring\n  Thick\n  Double\n  SingleDouble\n  DoubleSingle\n  Classic\n  Hidden\n  Custom(Border)\n}\n Represents different styles for drawing boxes.\n\nSingle\n\n\nRound\n\n\nSolid\n\n\nFrame\n\n\nCross\n\n\nSpring\n\n\nThick\n\n\nDouble\n\n\nSingleDouble\n\n\nDoubleSingle\n\n\nClassic\n\n\nHidden\n\n\nCustom(Border)\n\n\nSynonyms:\nwink.Style\nwink Style","url":"wink.html#Style"},{"doc":"wink","title":"default_config","content":"pub const default_config: Config = Config(\n  style: Round,\n  box_color: Default,\n  text_color: Default,\n  padding: Spacing(top: 1, right: 1, bottom: 1, left: 1),\n  margin: Spacing(top: 1, right: 1, bottom: 1, left: 1),\n  decorations: [],\n)\n Default configuration for drawing a box.\n\nSynonyms:\nwink.default_config\nwink default_config","url":"wink.html#default_config"},{"doc":"wink","title":"draw","content":"pub fn draw(msg: String) -&gt; String\n Draws a box with the default configuration.\n\nSynonyms:\nwink.draw\nwink draw","url":"wink.html#draw"},{"doc":"wink","title":"init","content":"pub fn init(cfg: Config) -&gt; Box\n Initializes a box with the given configuration.\n\nSynonyms:\nwink.init\nwink init","url":"wink.html#init"},{"doc":"wink","title":"wink","content":" A simple Gleam box drawing library\n","url":"wink.html"}]);